from .static import StaticRoute
from .objects import PrefixList, PrefixListEntry, RouteMap, RouteMapEntry

__all__ = (
    'StaticRoute',
    'PrefixList',
    'PrefixListEntry',
    'RouteMap',
    'RouteMapEntry'
)
